﻿param(
[Parameter(Mandatory=$True,
           helpmessage="Unique name to ensure data is counted only once and result can be identifed")]
           [string]$namespace,

[Parameter(Mandatory=$True,
           helpmessage="Enter directory where the exchange instance is located")]
           [string]$fcminstance, 

[Parameter(Mandatory=$True,
           helpmessage="Enter directory where the output should be written to")]
           [string]$directory             
)

$productId   = "12"
$productName = "IBM Spectrum Protect Snapshot for Microsoft Exchange"
$itemTtype   = "backup";

function queryUsageData()
{
   Write-Host "`nQuery protected Mailbox Databases"         
   $cmdOut = Get-MailboxDatabaseCopyStatus | where {$_.ActiveCopy -eq $true } | select name   

   if ($? -ne $True)
   {      
      exit
   }   
          
   return $cmdOut  
}

function parseUsageData($cmdOutFE, $cmdOutLU, $cmdOutBE)
{
   $splitLine = $False
   $dbNames = @()
   $dbSizeFE = 0
   $dbCount = 0
   $dbSizeBE = 0

   foreach ($db in $cmdOutFE)
   {
      $tokens = [regex]::Split($db.name, "\\")
      $dbNames += $tokens[0]
   }

   $cmdOutFE = Get-MailboxDatabase -status | where {$_.Recovery -eq $false } | select name,databasesize,last*

   foreach ($db in $cmdOutFE)
   {
      if ($dbNames -contains $db.name)
      {
         Write-Host "`nGetting size for" $db.name ":" $db.databasesize
         $sizeStr = $db.databasesize -replace ".+\((.+)\s\w+\)", '$1'
         $size = $sizeStr -replace ",", ""         
         $dbSizeFE += $size
         $dbCount +=1         
      }      
   }
   
   $dbSizeFE = [decimal]::round($dbSizeFE/1024/1024)

   $luSize = $cmdOutLU.Trim()
   $luSize = $luSize.TrimStart("TotalManagedCapacity")
   $luSize = $luSize.Trim()
   $luSize = $luSize.Replace("-", "") 
   $luSize = $luSize.Trim()
   [int]$dbSizeLU = [decimal]::round($luSize/1024/1024)
   
   foreach ($db in $cmdOutFE)
   {
      if ($dbNames -contains $db.name)
      {
         $sizeStr = $db.databasesize -replace ".+\((.+)\s\w+\)", '$1'
         [int]$sizeBE = $sizeStr -replace ",", "" 
         $sizeBE = $sizeBE*$cmdOutBE/1024/1024
         Write-Host "`nGetting back end size for" $db.name ":" $sizeBE "(MB)"       
         $dbSizeBE += $sizeBE    
      }      
   }
   $dbSizeBE = [decimal]::round($dbSizeBE)

   Write-Host "`nIBM Spectrum Protect Snapshot FE"
   Write-Host "------------------------------------------"
   Write-Host "Query result"
   Write-Host "Number of objects:  $dbCount"
   Write-Host "Exchange (fcm be):  $dbSizeFE (MB)"

   Write-Host "`nIBM Spectrum Protect Snapshot LUN"
   Write-Host "------------------------------------------"
   Write-Host "Query result"
   Write-Host "Exchange (fcm lun): $dbSizeLU (MB)" 

   Write-Host "`nIBM Spectrum Protect Snapshot BE"
   Write-Host "------------------------------------------"
   Write-Host "Query result"
   Write-Host "Snapshots:          $cmdOutBE" 
   Write-Host "Exchange (fcm be):  $dbSizeBE (MB)`n" 

   createXmlFile $dbCount $dbSizeFE
   
        
}

function fcmLU()
{
   $cmdStrLU = $fcminstance.Substring(1,$fcminstance.Length-2)
   $cmdStrLU = $cmdStrLU + "\FmModuleExc.dll"
   Import-Module $cmdStrLU
   $cmdOutLU = Invoke-Command -Command{Get-DpExcManagedCapacity | Out-String}

   return $cmdOutLU
}

function fcmBE()
{
   $cmdOutBE = Invoke-Command -Command{Get-DpExcBackup -all | Out-String}
   Remove-Module -Name FmModuleExc
   $cmdOutBE = $cmdOutBE.Replace("ExchangeServerName", "*")
   $count = ($cmdOutBE.ToCharArray() | Where-Object {$_ -eq '*'} | Measure-Object).Count
   
   return $count
}


function createXmlFile($dbCount, $dbSizeFE)
{ 
   $cmdStr = '.\dsmfecc "--create" "--namespace=$namespace" "--productid=$productId" "--directory=$directory" "--applicationentity=$namespace" "--numberofobjects=$dbCount" "--size=$dbSizeFE" "--type=$itemTtype" 2>&1'
   
   Write-Host "`nCreate XML file"
      
   Invoke-Expression $cmdStr
   if ($LastExitCode -ne 0)
   {
      Write-Host "Create XML file failed."      
      exit
   }    
}

Write-Host "`n"
Write-Host "********************************************************************"
Write-Host "********      IBM Spectrum Protect Suite - Front End       *********"
Write-Host "********          Terabyte (TB) Capacity Report            *********"
Write-Host "********************************************************************`n"
Write-Host "$productName`n"

$queryUsageDataOutput = queryUsageData
$queryLU = fcmLU
$queryBE = fcmBE
parseUsageData $queryUsageDataOutput $queryLU $queryBE


